Plot Topic Effects for Continuous Variables
Source:R/topic_modeling.R
plot_topic_effects_continuous.RdCreates a faceted plot showing how continuous variables affect topic proportions.
Usage
plot_topic_effects_continuous(
effects_data,
ncol = 2,
height = 800,
width = 1000,
title = "Continuous Variable Effects",
base_font_size = 11
)Arguments
- effects_data
Data frame with columns: topic, value, proportion, lower, upper
- ncol
Number of columns for faceting (default: 2)
- height
Plot height in pixels (default: 800)
- width
Plot width in pixels (default: 1000)
- title
Plot title (default: "Continuous Variable Effects")
- base_font_size
Base font size in points for the plot theme (default: 11). Axis text and strip text will be base_font_size + 2.
See also
Other topic-modeling:
analyze_semantic_evolution(),
assess_embedding_stability(),
assess_hybrid_stability(),
auto_tune_embedding_topics(),
calculate_assignment_consistency(),
calculate_keyword_stability(),
calculate_semantic_drift(),
calculate_topic_probability(),
calculate_topic_stability(),
find_optimal_k(),
find_topic_matches(),
fit_embedding_model(),
fit_hybrid_model(),
fit_temporal_model(),
fit_topic_prevalence_model(),
generate_topic_labels(),
get_topic_prevalence(),
get_topic_terms(),
get_topic_texts(),
identify_topic_trends(),
plot_model_comparison(),
plot_quality_metrics(),
plot_topic_effects_categorical(),
plot_topic_probability(),
plot_word_probability(),
run_neural_topics_internal(),
validate_semantic_coherence()