Plot Topic Effects for Continuous Variables
Source:R/topic_modeling.R
plot_topic_effects_continuous.RdCreates a faceted plot showing how continuous variables affect topic proportions.
Usage
plot_topic_effects_continuous(
effects_data,
ncol = 2,
height = 800,
width = 1000,
title = "Continuous Variable Effects",
base_font_size = 14
)Arguments
- effects_data
Data frame with columns: topic, value, proportion, lower, upper
- ncol
Number of columns for faceting (default: 2)
- height
Plot height in pixels (default: 800)
- width
Plot width in pixels (default: 1000)
- title
Plot title (default: "Continuous Variable Effects")
- base_font_size
Base font size in pixels for the plot theme (default: 14). Axis text and strip text will be base_font_size + 2.
See also
Other topic_modeling:
plot_topic_effects_categorical(),
plot_topic_probability(),
plot_word_probability()